Learn R Programming

HotDeckImputation (version 0.1.0)

HotDeckImputation-package: Hot Deck Imputation Methods for Missing Data

Description

This package provides hot deck imputation methods to resolve missing data. Methods provided are popular in survey methodology, mostly used in the context of large national statistics, but are also finding their way to data mining due to their computational simplicity. A key aspect of this package is the implementation of the commonly advocated donor-limit.

Arguments

Details

ll{ Package: HotDeckImputation Type: Package Version: 0.1.0 Date: 2013-08-12 License: GPL-3 } HotDeckImputation is the ever expanding implementation of hot deck imputation methods, such as the nearest neighbor, the CPS-sequential and random hot deck. The package aims to be comprehensive in the functionality provided, covering key aspects of hot deck imputation not found elsewhere. Currently implemented functions include: Nearest neighbor hot deck imputation. Development requests are welcome.

References

Andridge, R.R. and Little, R.J.A. (2010) A Review of Hot Deck Imputation for Survey Non-response. International Statistical Review. 78, 40--64. Bankhofer, U. and Joenssen, D.W. (2013) On limiting donor usage for imputation of missing data via hot deck methods. In: M. Spiliopoulou, L. Schmidt-Thieme, and R. Jannings (Eds.): Data Analysis, Machine Learning and Knowledge Discovery. Studies in Classification, Data Analysis and Knowledge Organization, 3--10. Berlin/Heidelberg: Springer. (forthcoming) Ford, B. (1983) An Overview of Hot Deck Procedures. In: W. Madow, H. Nisselson and I. Olkin (Eds.): Incomplete Data in Sample Surveys. New York: Academic Press, 185--207. Kalton, G. and Kasprzyk, D. (1986) The Treatment of Missing Survey Data. Survey Methodology. 12, 1--16. Sande, I. (1983) Hot-Deck Imputation Procedures. In: W. Madow, H. Nisselson and I. Olkin (Eds.): Incomplete Data in Sample Surveys. New York: Academic Press, 339--349.